Sovereign Grace Churches | Partner With Us
Author: Church Plant Media
Keywords: adoption, Church Planting, church, joining, join

# Partner With Us

### Is Your Church Looking for Partnership?

Maybe we can serve each other. We believe that churches need one another to remain faithful in advancing the gospel of Jesus Christ.

“Only let your manner of life be worthy of the gospel of Christ, so that whether I come and see you or am absent, I may hear of you that you are standing firm in one spirit, with one mind striving side by side for the faith of the gospel” (Philippians 1:27).

The history of Sovereign Grace cannot be told without the stories of existing churches being led by God to join us in our partnered mission through the experience of adoption. Here are just a few of them:

“We began pursuing relationship and association with Sovereign Grace approximately 6 years ago. During that time, we have developed many meaningful connections and friendships—brotherly and sisterly bonds that we hold very near and dear. This time, for us, has been nothing but a display of a gospel-saturated culture. After all, Christ has not only cared for His church, but He continues caring for His church! Sovereign Grace has shown this beyond dispute.”

Russell Tusing, Pastor in LaGrange, GA—Adopted 2014

“What God was doing in my church seemed to be mirrored in Sovereign Grace. We held similar values such as the priority of the gospel, sound doctrine, expository preaching, and the vital role of the Holy Spirit. I realized we were essentially a Sovereign Grace church though we were not officially a member. I also saw gospel fruit in so many of the people who had befriended us in Sovereign Grace and wanted that fruit in my life, my marriage, my children, and my church. We want to be part of what God is doing through Sovereign Grace: to preach Christ, and to plant and support Christ-exalting, gospel-centered churches.”

Rob Saathoff, Pastor in Buffalo, NY—Adopted 2013

“For many years now we have been encouraged and served by Sovereign Grace, whether through messages, conferences, music, or friendships. Sovereign Grace Church in Minnesota has been a model and source of encouragement for us. Their pastors have offered us advice when we needed it and even more encouragement at just the right time. We are thrilled to be in the Midwest-Northwest region and look forward with great anticipation to all that God will do both at Grace Life Fellowship and throughout every church in Sovereign Grace for the sake of Jesus’s name.”

Chad Haygood, Pastor in Hastings, NE—Adopted 2014

We recognize that the adoption of an existing church requires a careful process that is distinct from more conventional church planting. Let’s get to know each other as we help you get the information and input you need to explore whether there is alignment with Sovereign Grace’s theology, mission, values, and polity.

### WOULD YOU LIKE TO EXPLORE PARTNERING WITH US?